@@ -42,6 +42,7 @@
 #include <QWidget>
 #include <QApplication>
 #include <QTime>
+#include <QTimer>
 // local includes
 #include "common.h"
 #include "barcodedetector.h"
@@ -70,6 +71,9 @@ VideoWidget::VideoWidget(QWidget *parent, BarcodeDetector *decoder) : QWidget(pa
     getDeviceType(); // work out which device we are so we can specify what type of pipeline to setup
     initPipeline(); // create the GStreamer pipeline
     this->decoder = decoder; // create a new decoder object
+    QTimer *refocusTimer = new QTimer(this);
+    connect(refocusTimer, SIGNAL(timeout()), this, SLOT(refocus()));
+    refocusTimer->start(1500); // try to refocus every one-and-a-half seconds
 }
 
 VideoWidget::~VideoWidget() {
@@ -503,14 +507,14 @@ void VideoWidget::refocus() {
         emit focusingValueChanged(true);
         gst_element_set_state (pipeline, GST_STATE_PAUSED);
 
-        qDebug("ideoWidget::refocus(): Calling refocus");
+        qDebug("VideoWidget::refocus(): Calling refocus");
         focusing = true;
         gst_photography_set_autofocus(GST_PHOTOGRAPHY(camera_src), TRUE);
-        qDebug("ideoWidget::refocus(): Refocus called");
+        qDebug("VideoWidget::refocus(): Refocus called");
 //        gst_element_set_state (pipeline, GST_STATE_READY); // causes some problems with flickering, should probably be uncommented
         gst_element_set_state (pipeline, GST_STATE_PLAYING);
     } else {
-        qDebug("ideoWidget::refocus(): Already attempting autofocus... Please wait :)");
+        qDebug("VideoWidget::refocus(): Already attempting autofocus... Please wait :)");
     }
 }
 void VideoWidget::setFocusing(bool enabled) {
